@@ -770,15 +770,15 @@ class ShardedS3Dataset(Value):
 
     type_name = "redun.ShardedS3Dataset"
 
-    def __init__(self, path: str, format: str = "parquet", recurse: bool = False):
+    def __init__(self, path: str, format: str = "parquet", recurse: bool = True):
         path = path.rstrip("/")
-        self.path = path
-        self.recurse = recurse
+        self._path = path
+        self._recurse = recurse
         self._hash: Optional[str] = None
 
         if format not in ["avro", "csv", "ion", "grokLog", "json", "orc", "parquet", "xml"]:
             raise ValueError(f"Invalid format {format}")
-        self.format = format
+        self._format = format
 
         self.filesystem: FileSystem = get_filesystem(url=self.path)
         self._filenames: List[str] = self._gather_files()
@@ -786,9 +786,9 @@ class ShardedS3Dataset(Value):
     def _gather_files(self) -> List[str]:
 
         # If recursing, look in subdirectories too.
-        files = glob_file(f"{self.path}/*.{self.format}")
+        files = glob_file(f"{self._path}/*.{self._format}")
         if self.recurse:
-            files.extend(glob_file(f"{self.path}/**/*.{self.format}"))
+            files.extend(glob_file(f"{self._path}/**/*.{self._format}"))
 
         # Work around differences between fsspec's interpretation of ** on S3 vs.local
         # by removing any duplicate file names from the list.
@@ -801,6 +801,37 @@ class ShardedS3Dataset(Value):
         self.update_hash()
         return self
 
+    @property
+    def format(self) -> str:
+        return self._format
+
+    @format.setter
+    def format(self, value):
+        self._format = format
+        self._calc_hash()
+
+    @property
+    def recurse(self) -> bool:
+        return self._recurse
+
+    @recurse.setter
+    def recurse(self, value):
+        self._recurse = value
+        self._calc_hash()
+
+    @property
+    def filenames(self) -> List[str]:
+        return self._filenames
+
+    @property
+    def path(self) -> str:
+        return self._path
+
+    @path.setter
+    def path(self, value):
+        self._path = value
+        self._calc_hash()
+
     @property
     def hash(self) -> str:
         if not self._hash:
@@ -808,6 +839,11 @@ class ShardedS3Dataset(Value):
         return self._hash
 
     def _calc_hash(self) -> str:
+        """
+        Recalculates the hash of the dataset. We re-gather all the files at
+        this time as new files may have been created in the meantime, such as
+        writing output from a Spark/Glue job.
+        """
         self._filenames = self._gather_files()
         return hash_struct(["ShardedS3Dataset"] + sorted(self._filenames))
 
@@ -832,17 +868,17 @@ class ShardedS3Dataset(Value):
 
     def __getstate__(self) -> dict:
         return {
-            "path": self.path,
-            "format": self.format,
-            "recurse": self.recurse,
+            "path": self._path,
+            "format": self._format,
+            "recurse": self._recurse,
             "hash": self._hash,
             "files": self._filenames,
         }
 
     def __setstate__(self, state: dict) -> None:
-        self.path = state["path"]
-        self.format = state["format"]
-        self.recurse = state["recurse"]
+        self._path = state["path"]
+        self._format = state["format"]
+        self._recurse = state["recurse"]
         self._filenames = state["files"]
         self._hash = state["hash"]
 
