@@ -853,7 +853,7 @@ def test_simple_expression_upstreams(scheduler: Scheduler, session: Session) ->
     assert scheduler.run(main(1)) == 11
 
     # Redefine the task.
-    @task()  # type: ignore # noqa: F811
+    @task()  # type: ignore[no-redef]
     def get_data() -> dict:
         return {"key": -10}
 
